import { Obj, PointL, PointS, RectL } from "./Primitives";
import { Region } from "./Region";
import { Brush, ColorRef, Font, Pen } from "./Style";
export interface ISelectedStyle {
    brush?: Brush;
    pen?: Pen;
    font?: Font;
    region?: Region;
    path?: Path;
    [key: string]: Obj;
}
export declare class Path extends Obj {
    svgPath: any;
    constructor(svgPath: any, copy?: Path);
    clone(): Path;
    toString(): string;
}
export declare const _StockObjects: {
    [key: string]: Obj;
};
export declare class GDIContextState {
    _svggroup: any;
    _svgclipChanged: boolean;
    _svgtextbkfilter: any;
    mapmode: number;
    stretchmode: number;
    textalign: number;
    bkmode: number;
    textcolor: ColorRef;
    bkcolor: ColorRef;
    polyfillmode: number;
    miterlimit: number;
    wx: number;
    wy: number;
    ww: number;
    wh: number;
    vx: number;
    vy: number;
    vw: number;
    vh: number;
    x: number;
    y: number;
    nextbrx: number;
    nextbry: number;
    brx: number;
    bry: number;
    clip: Region;
    ownclip: boolean;
    selected: ISelectedStyle;
    constructor(copy: GDIContextState, defObjects?: ISelectedStyle);
}
export declare class GDIContext {
    private _svg;
    private _svgdefs;
    private _svgPatterns;
    private _svgClipPaths;
    private _svgPath;
    private defObjects;
    private state;
    private statestack;
    private objects;
    constructor(svg: any);
    setMapMode(mode: number): void;
    setWindowOrgEx(x: number, y: number): void;
    setWindowExtEx(x: number, y: number): void;
    setViewportOrgEx(x: number, y: number): void;
    setViewportExtEx(x: number, y: number): void;
    setBrushOrgEx(origin: PointL): void;
    saveDC(): void;
    restoreDC(saved: number): void;
    setStretchBltMode(stretchMode: number): void;
    rectangle(rect: RectL, rw: number, rh: number): void;
    lineTo(x: number, y: number): void;
    moveToEx(x: number, y: number): void;
    polygon(points: PointS[] | PointL[], bounds: RectL, first: boolean): void;
    polyPolygon(polygons: PointS[][] | PointL[][], bounds: RectL): void;
    polyline(isLineTo: boolean, points: PointS[], bounds: RectL): void;
    polybezier(isPolyBezierTo: boolean, points: PointS[], bounds: RectL): void;
    selectClipPath(rgnMode: number): void;
    selectClipRgn(rgnMode: number, region: Region): void;
    offsetClipRgn(offset: PointL): void;
    setTextAlign(textAlignmentMode: number): void;
    setMiterLimit(miterLimit: number): void;
    setBkMode(bkMode: number): void;
    setBkColor(bkColor: ColorRef): void;
    setPolyFillMode(polyFillMode: number): void;
    createBrush(index: number, brush: Brush): void;
    createPen(index: number, pen: Pen): void;
    createPenEx(index: number, pen: Pen): void;
    selectObject(objIdx: number, checkType: string): void;
    abortPath(): void;
    beginPath(): void;
    closeFigure(): void;
    fillPath(bounds: RectL): void;
    strokePath(bounds: RectL): void;
    endPath(): void;
    deleteObject(objIdx: number): void;
    private _pushGroup();
    private _getStockObject(idx);
    private _storeObject(obj, idx);
    private _getObject(objIdx);
    private _getSvgDef();
    private _getSvgClipPathForRegion(region);
    private _getSvgPatternForBrush(brush);
    private _selectObject(obj);
    private _deleteObject(objIdx);
    private _getClipRgn();
    private _todevX(val);
    private _todevY(val);
    private _todevW(val);
    private _todevH(val);
    private _tologicalX(val);
    private _tologicalY(val);
    private _tologicalW(val);
    private _tologicalH(val);
    private _applyOpts(opts, usePen, useBrush, useFont);
}
