export interface EMFJSError {
    name: string;
    message: string;
    stack: string;
}
export declare const EMFJSError: new (message: string) => EMFJSError;
export declare function loggingEnabled(enabled: boolean): void;
export declare class Helper {
    static GDI: {
        FormatSignature: {
            ENHMETA_SIGNATURE: number;
            EPS_SIGNATURE: number;
        };
        BITMAPINFOHEADER_SIZE: number;
        BITMAPCOREHEADER_SIZE: number;
        RecordType: {
            EMR_POLYBEZIER: number;
            EMR_POLYGON: number;
            EMR_POLYLINE: number;
            EMR_POLYBEZIERTO: number;
            EMR_POLYLINETO: number;
            EMR_POLYPOLYLINE: number;
            EMR_POLYPOLYGON: number;
            EMR_SETWINDOWEXTEX: number;
            EMR_SETWINDOWORGEX: number;
            EMR_SETVIEWPORTEXTEX: number;
            EMR_SETVIEWPORTORGEX: number;
            EMR_SETBRUSHORGEX: number;
            EMR_EOF: number;
            EMR_SETPIXELV: number;
            EMR_SETMAPPERFLAGS: number;
            EMR_SETMAPMODE: number;
            EMR_SETBKMODE: number;
            EMR_SETPOLYFILLMODE: number;
            EMR_SETROP2: number;
            EMR_SETSTRETCHBLTMODE: number;
            EMR_SETTEXTALIGN: number;
            EMR_SETCOLORADJUSTMENT: number;
            EMR_SETTEXTCOLOR: number;
            EMR_SETBKCOLOR: number;
            EMR_OFFSETCLIPRGN: number;
            EMR_MOVETOEX: number;
            EMR_SETMETARGN: number;
            EMR_EXCLUDECLIPRECT: number;
            EMR_INTERSECTCLIPRECT: number;
            EMR_SCALEVIEWPORTEXTEX: number;
            EMR_SCALEWINDOWEXTEX: number;
            EMR_SAVEDC: number;
            EMR_RESTOREDC: number;
            EMR_SETWORLDTRANSFORM: number;
            EMR_MODIFYWORLDTRANSFORM: number;
            EMR_SELECTOBJECT: number;
            EMR_CREATEPEN: number;
            EMR_CREATEBRUSHINDIRECT: number;
            EMR_DELETEOBJECT: number;
            EMR_ANGLEARC: number;
            EMR_ELLIPSE: number;
            EMR_RECTANGLE: number;
            EMR_ROUNDRECT: number;
            EMR_ARC: number;
            EMR_CHORD: number;
            EMR_PIE: number;
            EMR_SELECTPALETTE: number;
            EMR_CREATEPALETTE: number;
            EMR_SETPALETTEENTRIES: number;
            EMR_RESIZEPALETTE: number;
            EMR_REALIZEPALETTE: number;
            EMR_EXTFLOODFILL: number;
            EMR_LINETO: number;
            EMR_ARCTO: number;
            EMR_POLYDRAW: number;
            EMR_SETARCDIRECTION: number;
            EMR_SETMITERLIMIT: number;
            EMR_BEGINPATH: number;
            EMR_ENDPATH: number;
            EMR_CLOSEFIGURE: number;
            EMR_FILLPATH: number;
            EMR_STROKEANDFILLPATH: number;
            EMR_STROKEPATH: number;
            EMR_FLATTENPATH: number;
            EMR_WIDENPATH: number;
            EMR_SELECTCLIPPATH: number;
            EMR_ABORTPATH: number;
            EMR_COMMENT: number;
            EMR_FILLRGN: number;
            EMR_FRAMERGN: number;
            EMR_INVERTRGN: number;
            EMR_PAINTRGN: number;
            EMR_EXTSELECTCLIPRGN: number;
            EMR_BITBLT: number;
            EMR_STRETCHBLT: number;
            EMR_MASKBLT: number;
            EMR_PLGBLT: number;
            EMR_SETDIBITSTODEVICE: number;
            EMR_STRETCHDIBITS: number;
            EMR_EXTCREATEFONTINDIRECTW: number;
            EMR_EXTTEXTOUTA: number;
            EMR_EXTTEXTOUTW: number;
            EMR_POLYBEZIER16: number;
            EMR_POLYGON16: number;
            EMR_POLYLINE16: number;
            EMR_POLYBEZIERTO16: number;
            EMR_POLYLINETO16: number;
            EMR_POLYPOLYLINE16: number;
            EMR_POLYPOLYGON16: number;
            EMR_POLYDRAW16: number;
            EMR_CREATEMONOBRUSH: number;
            EMR_CREATEDIBPATTERNBRUSHPT: number;
            EMR_EXTCREATEPEN: number;
            EMR_POLYTEXTOUTA: number;
            EMR_POLYTEXTOUTW: number;
            EMR_SETICMMODE: number;
            EMR_CREATECOLORSPACE: number;
            EMR_SETCOLORSPACE: number;
            EMR_DELETECOLORSPACE: number;
            EMR_GLSRECORD: number;
            EMR_GLSBOUNDEDRECORD: number;
            EMR_PIXELFORMAT: number;
            EMR_DRAWESCAPE: number;
            EMR_EXTESCAPE: number;
            EMR_SMALLTEXTOUT: number;
            EMR_FORCEUFIMAPPING: number;
            EMR_NAMEDESCAPE: number;
            EMR_COLORCORRECTPALETTE: number;
            EMR_SETICMPROFILEA: number;
            EMR_SETICMPROFILEW: number;
            EMR_ALPHABLEND: number;
            EMR_SETLAYOUT: number;
            EMR_TRANSPARENTBLT: number;
            EMR_GRADIENTFILL: number;
            EMR_SETLINKEDUFIS: number;
            EMR_SETTEXTJUSTIFICATION: number;
            EMR_COLORMATCHTOTARGETW: number;
            EMR_CREATECOLORSPACEW: number;
        };
        MetafileEscapes: {
            NEWFRAME: number;
            ABORTDOC: number;
            NEXTBAND: number;
            SETCOLORTABLE: number;
            GETCOLORTABLE: number;
            FLUSHOUT: number;
            DRAFTMODE: number;
            QUERYESCSUPPORT: number;
            SETABORTPROC: number;
            STARTDOC: number;
            ENDDOC: number;
            GETPHYSPAGESIZE: number;
            GETPRINTINGOFFSET: number;
            GETSCALINGFACTOR: number;
            META_ESCAPE_ENHANCED_METAFILE: number;
            SETPENWIDTH: number;
            SETCOPYCOUNT: number;
            SETPAPERSOURCE: number;
            PASSTHROUGH: number;
            GETTECHNOLOGY: number;
            SETLINECAP: number;
            SETLINEJOIN: number;
            SETMITERLIMIT: number;
            BANDINFO: number;
            DRAWPATTERNRECT: number;
            GETVECTORPENSIZE: number;
            GETVECTORBRUSHSIZE: number;
            ENABLEDUPLEX: number;
            GETSETPAPERBINS: number;
            GETSETPRINTORIENT: number;
            ENUMPAPERBINS: number;
            SETDIBSCALING: number;
            EPSPRINTING: number;
            ENUMPAPERMETRICS: number;
            GETSETPAPERMETRICS: number;
            POSTSCRIPT_DATA: number;
            POSTSCRIPT_IGNORE: number;
            GETDEVICEUNITS: number;
            GETEXTENDEDTEXTMETRICS: number;
            GETPAIRKERNTABLE: number;
            EXTTEXTOUT: number;
            GETFACENAME: number;
            DOWNLOADFACE: number;
            METAFILE_DRIVER: number;
            QUERYDIBSUPPORT: number;
            BEGIN_PATH: number;
            CLIP_TO_PATH: number;
            END_PATH: number;
            OPEN_CHANNEL: number;
            DOWNLOADHEADER: number;
            CLOSE_CHANNEL: number;
            POSTSCRIPT_PASSTHROUGH: number;
            ENCAPSULATED_POSTSCRIPT: number;
            POSTSCRIPT_IDENTIFY: number;
            POSTSCRIPT_INJECTION: number;
            CHECKJPEGFORMAT: number;
            CHECKPNGFORMAT: number;
            GET_PS_FEATURESETTING: number;
            MXDC_ESCAPE: number;
            SPCLPASSTHROUGH2: number;
        };
        MapMode: {
            MM_TEXT: number;
            MM_LOMETRIC: number;
            MM_HIMETRIC: number;
            MM_LOENGLISH: number;
            MM_HIENGLISH: number;
            MM_TWIPS: number;
            MM_ISOTROPIC: number;
            MM_ANISOTROPIC: number;
        };
        StretchMode: {
            BLACKONWHITE: number;
            WHITEONBLACK: number;
            COLORONCOLOR: number;
            HALFTONE: number;
        };
        MixMode: {
            TRANSPARENT: number;
            OPAQUE: number;
        };
        BrushStyle: {
            BS_SOLID: number;
            BS_NULL: number;
            BS_HATCHED: number;
            BS_PATTERN: number;
            BS_INDEXED: number;
            BS_DIBPATTERN: number;
            BS_DIBPATTERNPT: number;
            BS_PATTERN8X8: number;
            BS_DIBPATTERN8X8: number;
            BS_MONOPATTERN: number;
        };
        PenStyle: {
            PS_COSMETIC: number;
            PS_ENDCAP_ROUND: number;
            PS_JOIN_ROUND: number;
            PS_SOLID: number;
            PS_DASH: number;
            PS_DOT: number;
            PS_DASHDOT: number;
            PS_DASHDOTDOT: number;
            PS_NULL: number;
            PS_INSIDEFRAME: number;
            PS_USERSTYLE: number;
            PS_ALTERNATE: number;
            PS_ENDCAP_SQUARE: number;
            PS_ENDCAP_FLAT: number;
            PS_JOIN_BEVEL: number;
            PS_JOIN_MITER: number;
            PS_GEOMETRIC: number;
        };
        PolygonFillMode: {
            ALTERNATE: number;
            WINDING: number;
        };
        BitmapCompression: {
            BI_RGB: number;
            BI_RLE8: number;
            BI_RLE4: number;
            BI_BITFIELDS: number;
            BI_JPEG: number;
            BI_PNG: number;
        };
        RegionMode: {
            RGN_AND: number;
            RGN_OR: number;
            RGN_XOR: number;
            RGN_DIFF: number;
            RGN_COPY: number;
        };
        StockObject: {
            WHITE_BRUSH: number;
            LTGRAY_BRUSH: number;
            GRAY_BRUSH: number;
            DKGRAY_BRUSH: number;
            BLACK_BRUSH: number;
            NULL_BRUSH: number;
            WHITE_PEN: number;
            BLACK_PEN: number;
            NULL_PEN: number;
            OEM_FIXED_FONT: number;
            ANSI_FIXED_FONT: number;
            ANSI_VAR_FONT: number;
            SYSTEM_FONT: number;
            DEVICE_DEFAULT_FONT: number;
            DEFAULT_PALETTE: number;
            SYSTEM_FIXED_FONT: number;
            DEFAULT_GUI_FONT: number;
            DC_BRUSH: number;
            DC_PEN: number;
        };
    };
    static _uniqueId: number;
    static log(message: string): void;
    static _makeUniqueId(prefix: string): string;
    static _writeUint32Val(uint8arr: Uint8Array, pos: number, val: number): void;
    static _blobToBinary(blob: Uint8Array): string;
}
