import { DIBitmap } from "./Bitmap";
import { Blob } from "./Blob";
import { Obj, PointS, Rect } from "./Primitives";
import { Region } from "./Region";
import { Brush, ColorRef, Font, Palette, Pen } from "./Style";
export interface ISelectedStyle {
    brush?: Brush;
    pen?: Pen;
    font?: Font;
    palette?: Palette;
    region?: Region;
    [key: string]: Obj;
}
export declare class GDIContextState {
    _svggroup: any;
    _svgclipChanged: boolean;
    _svgtextbkfilter: any;
    mapmode: number;
    stretchmode: number;
    textalign: number;
    bkmode: number;
    textcolor: ColorRef;
    bkcolor: ColorRef;
    polyfillmode: number;
    wx: number;
    wy: number;
    ww: number;
    wh: number;
    vx: number;
    vy: number;
    vw: number;
    vh: number;
    x: number;
    y: number;
    clip: Region;
    ownclip: boolean;
    selected: ISelectedStyle;
    constructor(copy: GDIContextState, defObjects?: ISelectedStyle);
}
export declare class GDIContext {
    private _svg;
    private _svgdefs;
    private _svgPatterns;
    private _svgClipPaths;
    private defObjects;
    private state;
    private statestack;
    private objects;
    constructor(svg: any);
    setMapMode(mode: number): void;
    setWindowOrg(x: number, y: number): void;
    setWindowExt(x: number, y: number): void;
    offsetWindowOrg(offX: number, offY: number): void;
    setViewportOrg(x: number, y: number): void;
    setViewportExt(x: number, y: number): void;
    offsetViewportOrg(offX: number, offY: number): void;
    saveDC(): void;
    restoreDC(saved: number): void;
    escape(func: number, blob: Blob, offset: number, count: number): void;
    setStretchBltMode(stretchMode: number): void;
    stretchDib(srcX: number, srcY: number, srcW: number, srcH: number, dstX: number, dstY: number, dstW: number, dstH: number, rasterOp: number, colorUsage: number, dib: DIBitmap): void;
    stretchDibBits(srcX: number, srcY: number, srcW: number, srcH: number, dstX: number, dstY: number, dstW: number, dstH: number, rasterOp: number, dib: DIBitmap): void;
    rectangle(rect: Rect, rw: number, rh: number): void;
    textOut(x: number, y: number, text: string): void;
    extTextOut(x: number, y: number, text: string, fwOpts: number, rect: Rect, dx: number[]): void;
    lineTo(x: number, y: number): void;
    moveTo(x: number, y: number): void;
    polygon(points: PointS[], first: boolean): void;
    polyPolygon(polygons: PointS[][]): void;
    polyline(points: PointS[]): void;
    ellipse(rect: Rect): void;
    excludeClipRect(rect: Rect): void;
    intersectClipRect(rect: Rect): void;
    offsetClipRgn(offX: number, offY: number): void;
    setTextAlign(textAlignmentMode: number): void;
    setBkMode(bkMode: number): void;
    setTextColor(textColor: ColorRef): void;
    setBkColor(bkColor: ColorRef): void;
    setPolyFillMode(polyFillMode: number): void;
    createBrush(brush: Brush): void;
    createFont(font: Font): void;
    createPen(pen: Pen): void;
    createPalette(palette: Palette): void;
    createRegion(region: Region): void;
    createPatternBrush(patternBrush: Brush): void;
    selectObject(objIdx: number, checkType: string): void;
    deleteObject(objIdx: number): void;
    private _pushGroup();
    private _storeObject(obj);
    private _getObject(objIdx);
    private _getSvgDef();
    private _getSvgClipPathForRegion(region);
    private _getSvgPatternForBrush(brush);
    private _selectObject(obj);
    private _deleteObject(objIdx);
    private _getClipRgn();
    private _todevX(val);
    private _todevY(val);
    private _todevW(val);
    private _todevH(val);
    private _tologicalX(val);
    private _tologicalY(val);
    private _tologicalW(val);
    private _tologicalH(val);
    private _applyOpts(opts, usePen, useBrush, useFont);
}
